[PATCH] gcc parallel make check
Mike Stump
mikestump@comcast.net
Mon Sep 15 17:45:00 GMT 2014
On Sep 15, 2014, at 9:05 AM, Jakub Jelinek <jakub@redhat.com> wrote:
All the updates sound good.
> Regtested on x86_64-linux, without the patch toplevel make -k check
> took 8hrs3minutes (don't have time data for that run),
This confuses me, but, no matter. Isn’t 8hrs time data? :-)
> patch toplevel make -j48 -k check took:
> real 40m21.984s
> user 341m51.675s
> sys 112m46.993s
> and with the patch make -j48 -k check took:
> real 32m22.066s
> user 355m1.788s
> sys 117m5.809s
These numbers are useful to try and ensure the overhead (scaling factor) is reasonable, thanks.
> Is this version ok for trunk?
Ok.
Thanks for all your work.
More information about the Fortran
mailing list